# $Revision: 1.132 $, $Date: 2007/03/20 13:33:55 $
# TODO:
#	- sparc64 modules support in sparc(32), x86_64 modules support in i386 version
#	- make internal commands work even if busybox is not in /bin/busybox (initrd)
#	  or when /proc is not mounted (static / normal)
#
# Conditional build:
# alternative busybox config file (replaces default one) you should
# define cfgfile macro, i.e.
#
#	rpm --rebuild busybox.*.src.rpm --with altconfig --define "cfgfile bb-emb-config.h"
%bcond_with	altconfig	# use alternative config (defined by cfgfile)
%bcond_with	linkfl		# creates links to busybox binary and puts them into file list
# Options below are useful, when you want fileutils and grep providing.
# For example, ash package requires fileutils and grep.
%bcond_with	fileutl_prov	# adds fileutils providing
%bcond_with	grep_prov	# adds grep providing
# Option below is useful, when busybox is built with shell support.
%bcond_with	sh_prov		# adds /bin/sh providing
# WARNING! Shell, fileutils and grep providing may depend on config file!
# Fileutils, grep and shell provided with busybox have not such
# functionality as their GNU countenders.
#
%bcond_without	static		# don't build static version
%bcond_without	initrd		# don't build initrd version
#%%bcond_with	dietlibc	# build dietlibc-based initrd version
%bcond_with	glibc		# build glibc-based initrd version
#
%ifnarch %{ix86} %{x8664} ppc sparc64
%define with_glibc 1
%endif
%ifarch ppc
%undefine	with_dietlibc
%endif
Summary:	Set of common unix utils for embeded systems
Summary(pl.UTF-8):	Zestaw narzędzi uniksowych dla systemów wbudowanych
Summary(pt_BR.UTF-8):	BusyBox é um conjunto de utilitários UNIX em um único binário
Name:		busybox
Version:	1.4.2
Release:	1
License:	GPL
Group:		Applications
Source0:	http://www.busybox.net/downloads/%{name}-%{version}.tar.bz2
# Source0-md5:	b4c61fb15642be9dde20e8493788c585
Source1:	%{name}.config
Source2:	%{name}-initrd.config
%{?with_altconfig:Source3:	%{cfgfile}}
Patch1:		%{name}-logconsole.patch
Patch2:		%{name}-printf-gettext.patch
Patch3:		%{name}-loadfont.patch
Patch4:		%{name}-ash_exec.patch
Patch5:		%{name}-kernel_headers.patch
Patch6:		%{name}-insmod-morearchs.patch
Patch7:		%{name}-dhcp.patch
Patch8:		%{name}-fix_64_archs.patch
Patch9:		%{name}-noerror.patch
URL:		http://www.busybox.net/
BuildRequires:	gcc >= 3.2
BuildRequires:	perl-tools-pod
BuildRequires:	rpmbuild(macros) >= 1.333
%{?with_static:BuildRequires:	glibc-static}
%if %{with initrd}
	%if %{with dietlibc}
BuildRequires:	dietlibc-static
	%else
		%if %{with glibc}
BuildRequires:	glibc-static
		%else
%if "%{_target_base_arch}" != "%{_arch}"
BuildRequires:	cross%{_target_base_arch}-uClibc-static
%else
	%ifarch ppc %{x8664}
BuildRequires:	uClibc-static >= 2:0.9.29
	%else
BuildRequires:	uClibc-static >= 2:0.9.21
	%endif
%endif
		%endif
	%endif
%endif
%{?with_fileutl_prov:Provides:	fileutils}
%{?with_grep_prov:Provides:	grep}
%{?with_sh_prov:Provides:	/bin/sh}
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%define		_bindir		/bin
%define		_initrd_bindir	/bin

%if "%{_target_base_arch}" != "%{_arch}"
	%define CrossOpts CROSS="%{_target_cpu}-pld-linux-"
%else
	%define CrossOpts %{nil}
%endif

%description
BusyBox combines tiny versions of many common UNIX utilities into a
single small executable. It provides minimalist replacements for most
of the utilities you usually find in fileutils, shellutils, findutils,
textutils, grep, gzip, tar, etc. BusyBox provides a fairly complete
POSIX environment for any small or embedded system. The utilities in
BusyBox generally have fewer options than their full-featured GNU
cousins; however, the options that are included provide the expected
functionality and behave very much like their GNU counterparts.

BusyBox has been written with size-optimization and limited resources
in mind. It is also extremely modular so you can easily include or
exclude commands (or features) at compile time. This makes it easy to
customize your embedded systems. To create a working system, just add
a kernel, a shell (such as ash), and an editor (such as elvis-tiny or
ae).

%description -l pl.UTF-8
BusyBox składa małe wersje wielu narzędzi uniksowych w jeden mały plik
wykonywalny. Zapewnia minimalne zastępniki większości narzędzi
zawartych w pakietach fileutils, shellutils, findutils, grep, gzip,
tar itp. BusyBox daje w miarę kompletne środowisko POSIX dla małych
lub wbudowanych systemów. Narzędzia mają mniej opcji niż ich pełne
odpowiedniki GNU, ale mają podstawową funkcjonalność. Do działającego
systemu potrzeba jeszcze tylko kernela, shella (np. ash) oraz edytora
(np. elvis-tiny albo ae).

%description -l pt_BR.UTF-8
BusyBox combina versões reduzidas de muitos utilitários UNIX num único
executável, fornecendo substitutos minimalistas para muitos dos
executáveis encontrados em pacotes como fileutils, shellutils,
findutils, textutils, grep, gzip, tar, etc. Os utilitários do BusyBox
em geral têm menos opções que os utilitários GNU, mas as opções
implementadas comportam-se de maneira similar aos equivalentes GNU.

%package static
Summary:	Static busybox
Summary(pl.UTF-8):	Statycznie skonsolidowany busybox
Group:		Applications

%description static
Static busybox.

%description static -l pl.UTF-8
Statycznie skonsolidowany busybox.

%package initrd
Summary:	Static busybox for initrd
Summary(pl.UTF-8):	Statycznie skonsolidowany busybox dla initrd
Group:		Applications
Conflicts:	geninitrd < 3075

%description initrd
Static busybox for initrd.

%description initrd -l pl.UTF-8
Statycznie skonsolidowany busybox dla initrd.

%prep
%setup -q
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch6 -p1
%patch7 -p1
%patch8 -p1
%patch9 -p1

%build
install -d built
%if %{with initrd}
install %{SOURCE2} .config
%{__make} oldconfig
%{__make} \
	CROSS_CFLAGS="%{rpmcflags} -Os -D_BSD_SOURCE" \
	LDFLAGS="%{ld_rpmldflags} -static" \
%if %{with dietlibc}
	LIBRARIES="-lrpc" \
	CC="diet gcc"
%else
%if %{with glibc}
	%{CrossOpts} \
	CC="%{__cc}"
%else
    %if "%{_target_base_arch}" != "%{_arch}"
	CROSS="%{_target_cpu}-uclibc-" \
    %endif
	CC="%{_target_cpu}-uclibc-gcc"
%endif
%endif

mv -f busybox built/busybox.initrd
%{__make} clean
%endif


%if %{with altconfig}
install %{SOURCE3} .config
%else
install %{SOURCE1} .config
%endif

%if %{with static}
%{__make} oldconfig
%{__make} \
	%{CrossOpts} \
	CFLAGS_EXTRA="%{rpmcflags}" \
	LDFLAGS="%{ld_rpmldflags} -static" \
	CC="%{__cc}"
mv -f busybox built/busybox.static
%{__make} clean
%endif

%{__make} oldconfig
%{__make} \
	%{CrossOpts} \
	CFLAGS_EXTRA="%{rpmcflags}" \
	LDFLAGS="%{ld_rpmldflags}" \
	CC="%{__cc}"
%{__make} busybox.links docs/BusyBox.1

%install
rm -rf $RPM_BUILD_ROOT
install -d $RPM_BUILD_ROOT{%{_initrd_bindir},%{_bindir},%{_mandir}/man1,%{_libdir}/busybox}

%{?with_static:install built/busybox.static $RPM_BUILD_ROOT%{_bindir}}
%{?with_initrd:install built/busybox.initrd $RPM_BUILD_ROOT%{_initrd_bindir}/initrd-busybox}

install busybox.links $RPM_BUILD_ROOT%{_libdir}/busybox
install docs/BusyBox.1 $RPM_BUILD_ROOT%{_mandir}/man1
echo ".so BusyBox.1" > $RPM_BUILD_ROOT%{_mandir}/man1/busybox.1

# install links to busybox binary, when linkfl is defined
%if %{with linkfl}
%{__make} install \
	PREFIX=$RPM_BUILD_ROOT
%else
install busybox $RPM_BUILD_ROOT%{_bindir}
%endif

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(644,root,root,755)
%doc AUTHORS README .config

%if %{with linkfl}
%attr(755,root,root) /bin/*
%attr(755,root,root) /sbin/*
%attr(755,root,root) %{_bindir}/*
%attr(755,root,root) %{_sbindir}/*
%else
%attr(755,root,root) %{_bindir}/busybox
%endif

%{_libdir}/busybox
%{_mandir}/man1/*

%if %{with static}
%files static
%defattr(644,root,root,755)
%attr(755,root,root) %{_bindir}/busybox.static
%endif

%if %{with initrd}
%files initrd
%defattr(644,root,root,755)
%attr(755,root,root) %{_initrd_bindir}/initrd-busybox
%endif

%define date	%(echo `LC_ALL="C" date +"%a %b %d %Y"`)
%changelog
* %{date} PLD Team <feedback@pld-linux.org>
All persons listed below can be reached at <cvs_login>@pld-linux.org

$Log: busybox.spec,v $
Revision 1.132  2007/03/20 13:33:55  arekm
- up to 1.4.2

Revision 1.131  2007/03/18 00:13:19  arekm
- rel 2

Revision 1.130  2007/03/17 18:27:12  qboosh
- enabled DIRNAME/BASENAME applets in initrd config (merged from AC-branch)

Revision 1.129  2007/03/07 08:02:52  arekm
- up to 1.4.1

Revision 1.128  2007/02/12 21:23:50  glen
- tabs in preamble

Revision 1.127  2007/02/12 00:48:41  baggins
- converted to UTF-8

Revision 1.126  2007/01/27 21:10:27  arekm
- rel 1

Revision 1.125  2007/01/23 14:17:10  tommat
- configs updated,
- please test and give rel 1

Revision 1.124  2007/01/23 13:28:42  tommat
- up to 1.4.0
- removed already applied patches
- builds but configs needs to be adjusted, rel 0.1

Revision 1.123  2006/12/31 23:45:21  arekm
- rel 2; drop Werror

Revision 1.122  2006/12/31 14:09:34  sparky
- use %ld_rpmldflags

Revision 1.121  2006/12/30 13:29:30  qboosh
- updated to 1.3.1, updated configs
- updated printf-gettext,loadfont,dhcp patches
- readded LFS patch (only one part left, the rest is obsolete at last)
- added noshadow patch to fix build without shadow support

Revision 1.120  2006/11/09 17:50:26  qboosh
- sparc64_fixes patch merged into insmod-morearchs patch

Revision 1.119  2006/10/28 15:57:58  sparky
- try to support crosscompilation (static-uclibc version builds fine)

Revision 1.118  2006/10/27 19:14:22  arekm
- up to 1.2.2

Revision 1.117  2006/10/17 15:58:24  glen
- don't copy config just to copy it over with abother one

Revision 1.116  2006/08/09 15:44:42  sparky
- extended TODO: non-initrd version uses /proc/self/exe to detect its binary,
  but /proc needs to be mounted

Revision 1.115  2006/08/01 00:05:27  sparky
- up to 1.2.1

Revision 1.114  2006/07/20 17:48:31  qboosh
- updated insmod-morearchs patch

Revision 1.113  2006/07/18 23:27:12  sparky
- linked with uclibc works well on x8664, but AFAIK requires last one
- dietlibc is not supported, there is no 'getmntent_r'
- there is no CFLAGS_EXTRA variable, use CROSS_CFLAGS

Revision 1.112  2006/07/18 07:21:51  glen
- typo, cosmetics

Revision 1.111  2006/07/17 17:40:38  sparky
- added fixes patch

Revision 1.110  2006/07/17 17:09:05  sparky
- updated to 1.2.0
- removed force-dietlibc.patch, but dietlibc seems to be totally unsupported
- epoch for uClibc, and version 0.9.29 for ppc

Revision 1.109  2006/05/18 21:47:17  areq
- 1.1.3

Revision 1.108  2006/04/29 22:32:51  areq
- 1.1.2

Revision 1.107  2006/03/25 20:36:31  arekm
- updated to 1.1.1 (dropped obsolete pivot_root, raid_start, LFS, lzma, switchroot patches)

Revision 1.106  2006/01/10 20:12:47  sparky
- uClibc static version works on ppc, but not yet released uClibc is
  required on recent kernels, old one segfaults on program exit

Revision 1.105  2005/09/03 19:09:00  areq
- 1.01

Revision 1.104  2005/06/05 14:47:56  areq
- add cvs-20050604.patch - now build with gcc4
- add lzmacat applet

Revision 1.103  2005/02/15 13:55:23  tommat
- added LFS and ftpput patches

Revision 1.102  2005/02/02 20:55:21  hawk
- updated to final 1.00
- release 2 (1 for RA)

Revision 1.101  2005/01/16 18:08:28  malekith
- rel .3
- add 64bit fix patch for awk, which fixes problem with initrd
  failing to find root=
- STBR for AC please

Revision 1.100  2004/11/07 11:41:12  paladine
- cosmetics

Revision 1.99  2004/09/25 21:25:02  arekm
- rel .2

Revision 1.98  2004/09/25 18:13:49  arekm
- add switchroot

Revision 1.97  2004/08/16 14:48:09  areq
- 1.0rc3

Revision 1.96  2004/07/26 18:36:40  qboosh
- removed obsolete readahead patch

Revision 1.95  2004/07/26 15:05:35  averne
- updated to 1.00-rc2

Revision 1.94  2004/07/20 13:31:59  areq
- 1.00rc1

Revision 1.93  2004/06/24 19:31:45  arekm
- internal commands now work

Revision 1.92  2004/06/24 17:05:55  arekm
- rel4; support math in ash for initrd

Revision 1.91  2004/06/05 18:37:20  arekm
- request more variables from dhcp

Revision 1.90  2004/06/05 15:34:41  arekm
- initrd version includes chroot utility

Revision 1.89  2004/05/14 16:18:44  qboosh
- added todo (sparc64 modules support in sparc(32) version)

Revision 1.88  2004/05/14 14:58:12  qboosh
- updated printf-gettext,insmod-morearchs patches
- removed obsolete print_ascii,malloc,amd64 patches

Revision 1.87  2004/05/07 13:17:00  areq
- add busybox-readahead.patch (s/readahead/read_ahead/)

Revision 1.86  2004/04/15 19:34:59  areq
- 1.0pre10 - outdated patches ?

Revision 1.85  2004/03/16 15:11:31  qboosh
- it uses C99 syntax, BR: gcc 3

Revision 1.84  2004/02/23 19:35:24  areq
- 1.0.0pre8

Revision 1.83  2004/02/04 13:43:13  areq
- 1.0.0pre7

Revision 1.82  2004/01/31 11:14:47  areq
- 1.0.0pre6

Revision 1.81  2003/12/26 13:18:37  qboosh
- added insmod-morearchs patch with defines for alpha and possibly sparc
- some cleanups

Revision 1.80  2003/12/25 19:23:00  arekm
- added conflicts

Revision 1.79  2003/12/25 19:00:31  arekm
- updated to pre5

Revision 1.78  2003/12/21 17:22:10  jajcus
- compilation with userspace kernel headers fixed (-kernel_headers.patch)

Revision 1.77  2003/12/21 15:34:24  arekm
- add initial support for amd64

Revision 1.76  2003/12/11 14:15:10  areq
- add print_ascii.patch

Revision 1.75  2003/12/11 09:42:32  areq
- start update to pre4

Revision 1.74  2003/10/25 13:25:41  ankry
- pl: linkowanie -> konsolidacja, shell -> powłoka

Revision 1.73  2003/09/19 13:20:57  arekm
- BR: uClibc-static >= 0.9.21 (initrd-busybox segfaults with older versions)

Revision 1.72  2003/09/15 19:05:12  arekm
- fix insmod_ng (was broken in previous release of pre3)

Revision 1.71  2003/09/12 21:49:36  areq
- remove outdated insmod-gpl.patch

Revision 1.70  2003/09/12 20:02:28  areq
- start update to pre3

Revision 1.69  2003/09/03 15:14:39  qboosh
- typo, use just ifnarch

Revision 1.68  2003/09/03 15:12:11  malekith
- added --with glibc to compile initrd version with regular glibc-static
  (to be used on non x86 platforms, since there are severe problems with
   x86-centric uClibc)
- release .8

Revision 1.67  2003/08/24 20:55:27  blues
- renumbered patches

Revision 1.66  2003/08/24 10:50:43  malekith
- patch ash_exec: don't bailout when there's only /bin/sh, not /bin/busybox
- release .7

Revision 1.65  2003/08/24 10:37:36  malekith
- remove -config.patches (not used)

Revision 1.64  2003/08/18 08:07:56  gotar
- mass commit: cosmetics (removed trailing white spaces)

Revision 1.63  2003/08/15 21:45:25  malekith
- fixed raid_start to allow more then one device
- release 0.pre.6

Revision 1.62  2003/08/07 19:56:42  arekm
- rename initrd busybox binary

Revision 1.61  2003/08/07 11:00:27  blues
- reverted last change (really no other better way??)

Revision 1.60  2003/08/06 21:53:03  blues
- cosmetics

Revision 1.59  2003/08/06 16:39:12  kloczek
- może wrescie ktoś wykasuje to konto ?

Revision 1.58  2003/08/05 21:42:36  arekm
- added support for loading GPL_ modules

Revision 1.57  2003/08/03 10:45:44  arekm
- move busybox.initrd to /bin

Revision 1.56  2003/08/02 23:49:08  arekm
- switch to uClibc but leave dietlibc in bcond

Revision 1.55  2003/08/02 22:52:46  arekm
- updated to 1.0.0pre2.
  TODO:
    - fix patch nr 3
    - fix default config and create minimal config for initrd version
    - check compilation with dietlibc and uClibc

Revision 1.54  2003/07/01 01:21:57  malekith
- added insmod_ng patch with 2.5 kernel support
- can be also called as insmod, when 2.5 kernel is detetected -- insmod_ng
  is run

Revision 1.53  2003/07/01 00:02:35  malekith
- reorder patches; config patches get high numbers
- add raid_start support

Revision 1.52  2003/06/30 23:06:35  malekith
- store configuration in patch, don't overwrite original file

Revision 1.51  2003/06/30 22:56:05  malekith
- added initrd subpackage (busybox linked against dietlibc as bsp
  replacement)
- release 2

Revision 1.50  2003/06/30 22:25:24  malekith
- remove not needed cread and child patches
- still not sure about malloc though

Revision 1.49  2003/06/30 22:10:22  malekith
- new style bconds

Revision 1.48  2003/05/28 12:58:47  malekith
- massive attack: source-md5

Revision 1.47  2003/05/25 05:46:05  misi3k
- massive attack s/pld.org.pl/pld-linux.org/

Revision 1.46  2002/10/27 11:48:14  areq
- 0.60.5
- update logconsole.patch
- update URL, link SOURCE, switch to bz2
- comment patch 5,6,8 - outdated ?

Revision 1.45  2002/10/10 12:26:29  marcus
- use new %doc

Revision 1.44  2002/07/29 11:59:18  malekith
- added child.patch so busybox init will take over orphaned processes
  thus preventing zilions of Z processes on bootdisk
- release 8

Revision 1.43  2002/05/16 20:02:40  qboosh
- added Config.h to doc (may be useful - to know what capabilities are set)

Revision 1.42  2002/05/10 12:57:09  wrobell
- do not install busybox binary twice when using linkfl option
- rel. 7

Revision 1.41  2002/05/10 12:17:10  wrobell
- added new options:
  - altconfig     - build busybox with alternative busybox config file
  - linkfl        - creates links to busybox binary and includes them into filelist
  - fileutil_prov - adds fileutils providing
  - grep_prov     - adds grep providing
  - sh_prov       - adds /bin/sh providing
- rel. 6

Revision 1.40  2002/04/25 15:56:05  arturs
- fixed a small typo

Revision 1.39  2002/04/25 09:06:54  kloczek
- updated to 0.60.2 (release 5).

Revision 1.38  2002/04/25 08:39:04  kloczek
- merge translations from Conectiva.

Revision 1.37  2002/03/08 14:35:09  malekith
- pass CC to make

Revision 1.36  2002/03/05 18:09:01  marcus
- remove uclibc stuff
- rel.17.

Revision 1.35  2002/02/23 01:33:37  kloczek
- adapterized.

Revision 1.34  2002/02/22 23:28:44  kloczek
- removed all Group fields translations (our rpm now can handle translating
  Group field using gettext).

Revision 1.33  2002/01/21 18:15:46  malekith
- BOOT -> embed
- rel 16

Revision 1.32  2002/01/18 02:12:32  kloczek
- perl -pi -e "s/pld-list\@pld.org.pl/feedback\@pld.org.pl/"

Revision 1.31  2002/01/17 13:28:59  qboosh
- removed obsolete TODO comment

Revision 1.30  2002/01/17 13:26:51  qboosh
- release 15: added -static subpackage

Revision 1.29  2001/10/29 19:14:40  malekith
- rel 14
- new version of malloc patch and new pivot_root patch

Revision 1.28  2001/09/07 23:33:00  klakier
- removed sh_name.patch

Revision 1.27  2001/09/07 23:19:12  klakier
- config changed: disables ash, vi, enables lash
  Reasons:
  1) busybox ash makes trouble (crashes on some scripts) and is
     horribly slow
  2) _extremely_ small vi applet is provided by e3 package
  3) lash is poor bu it has some nice interactive features (completion, history)

  Please do not introduce substantial changes to this package without
  testing the results before! If you really need changes please consult them
  on one of pld mailing lists!!!

Revision 1.26  2001/08/30 22:42:48  filon
- updated to 0.60.1 (modified patches)
- there are much more applets (ash, vi, ..)
- it's smaller than ever before
- added ash to config, it's much smaller than ash-BOOT

Revision 1.25  2001/08/28 12:13:24  wiget
- fix BOOT subpackage
  release 12

Revision 1.24  2001/08/19 15:47:05  kloczek
- remove -s from LDFLAGS.

Revision 1.23  2001/08/18 11:03:00  malekith
- fixed, now builds correctly

Revision 1.22  2001/08/18 09:41:38  malekith
- fixes insmod problems with 3c boomerang
- rel 11

Revision 1.21  2001/08/09 16:37:24  qboosh
- base package is dynamically linked and has pl summary/description
- fixed BOOT bcond

Revision 1.20  2001/08/01 12:36:44  malekith
- enabled nc (netcat)

Revision 1.19  2001/07/30 15:51:56  klakier
- rel 9
- syslogd and klogd added to Config.h

Revision 1.18  2001/07/05 10:35:41  kloczek
- BuildRequires for uClibc-devel-BOOT only when %{BOOT is defined.

Revision 1.17  2001/07/05 08:49:06  wiget
- added pivot_root and freeramdisk; release 8

Revision 1.16  2001/06/13 09:23:30  malekith
- rel 7
- added cread patch (can anybody check if it works?)

Revision 1.15  2001/06/12 13:25:51  klakier
- rel 6
- loadfont added to config
- added loadfont.patch to be able to load lat2-16 font
  (THIS PATCH IS VERY NASTY HACK, but works)

Revision 1.14  2001/05/31 15:14:26  malekith
- added printf-gettext batch by /me
- rel 5

Revision 1.13  2001/05/22 22:51:05  klakier
- added -m386 for BOOT

Revision 1.12  2001/05/21 19:02:36  klakier
- rel 4
- compiled against uClibc 20010521

Revision 1.11  2001/05/21 11:41:41  klakier
- fixed broken 'cosmetics' from rev 1.9. Please DO NOT make
  substantial changes in %build or %install without testing it

Revision 1.10  2001/05/20 10:53:48  klakier
- rel 3 (fixed sh_name.patch)

Revision 1.9  2001/05/20 10:16:18  kloczek
- cosmetics.

Revision 1.8  2001/05/19 11:20:40  klakier
- added sh_name patch and change /bin/sh to /bin/lash (sh is in ash-BOOT)

Revision 1.7  2001/05/16 15:14:05  klakier
- changes

Revision 1.6  2001/04/24 04:42:17  kloczek
- release 2.

Revision 1.5  2001/04/13 13:56:14  klakier
- added BOOT package
- linked statically against uClibc

Revision 1.4  2001/04/11 22:26:33  kloczek
- removed outdated 0.50 patch.

Revision 1.3  2001/04/11 20:37:46  areq
- 0.51
- comment busybox-0.50.patch

Revision 1.2  2001/04/04 18:09:00  kloczek
- added more %description,
- added full Source url,
- move busybox executable to %{_bindir},
- added man page for busybox,
- some style fixes in %install.

Revision 1.1  2001/04/03 17:06:40  malekith
- from scratch.
